#
# spec file for package perl-BSD-Resource
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name BSD-Resource
Name:           perl-BSD-Resource
Version:        1.291.100
Release:        1.1
# 1.2911 -> normalize -> 1.291.100
%define cpan_version 1.2911
#Upstream:  This module free software; you can redistribute it and/or modify it under the terms of the Artistic License 2.0 or GNU Lesser General Public License 2.0. For more details, see the full text of the licenses at <http://www.perlfoundation.org/artistic_license_2_0>, and <http://www.gnu.org/licenses/gpl-2.0.html>.
License:        Artistic-2.0 OR LGPL-2.0-only
Summary:        BSD process resource limit and priority functions
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JH/JHI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(BSD::Resource) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
BSD process resource limit and priority functions

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README
%license LICENSE

%changelog
* Mon Jun 23 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Tue Apr 11 2017 coolo@suse.com
- updated to 1.2911
  see /usr/share/doc/packages/perl-BSD-Resource/ChangeLog
  2017-04-07  Jarkko Hietaniemi  <jhi@iki.fi>
  * Prepend "./" to require-d pathnames in tests,
  in preparation of Perl 5.26.0. [cpan #120993]
  * Add RLIMIT_POSIXLOCKS from DragonFly BSD.
  * Release 1.2911.
* Sat May 28 2016 coolo@suse.com
- updated to 1.2910
  see /usr/share/doc/packages/perl-BSD-Resource/ChangeLog
  2016-05-12  Jarkko Hietaniemi  <jhi@iki.fi>
  * Add RLIMIT_RSESTACK from hpux/ia64, and RLIMIT_FREEMEM
  and RLIMIT_NTHR from QNX.
  * Add more PRIO_ values from Solaris:
  PRIO_CONTRACT
  PRIO_LWP
  PRIO_PROJECT
  PRIO_SESSION
  PRIO_TASK
  PRIO_ZONE
  * HPUX: Do not unconditionally define the RLIMIT_ and RLIM_NLIMITS
  * Add missing word ('enough') in getrusage.t test skippage.
  * Repoint all the license pointers to COPYRIGHT and LICENSE
  in Resource.pm, add LICENSE file as a new pointer.
  * Release 1.2910.
* Mon Nov 16 2015 coolo@suse.com
- updated to 1.2909
  see /usr/share/doc/packages/perl-BSD-Resource/ChangeLog
  2015-11-15  Jarkko Hietaniemi  <jhi@iki.fi>
  * The added RLIMIT_ values were not added quite right.
  Our own tests didn't detect this, but mod_perl2 ones did
  [cpan #108955]
* Sat Oct 24 2015 coolo@suse.com
- updated to 1.2908
  see /usr/share/doc/packages/perl-BSD-Resource/ChangeLog
- fix license - it's not apache
* Fri Jul 26 2013 coolo@suse.com
- updated to 1.2907
  * Address rt.cpan.org #86857: t/setrlimit.t failure
    Skip setrlimit() tests also if the hard limit is RLIM_INFINITY.
  * Release 1.2907.
  2013-07-07  Jarkko Hietaniemi  <jhi@iki.fi>
  * Skip number-of-files and stack setrlimit tests in Cygwin:
    the constants exist but the implementation doesn't really
    seem to be there.  Document this in the pod.  Testing by dsolimano.
  * For setrlimit tests involving byte sizes (memory or file size)
    round the byte sizes down to 4 kB boundaries.
  * Fix some pod nits.
  * Release 1.2906.
  2013-06-22  Jarkko Hietaniemi  <jhi@iki.fi>
  * Address rt.cpan.org #86334: typo fixes
  * Address rt.cpan.org #62504: Disable user/system
    timing tests if workload accumulate too little time
  * Attempt harder in getrusage.t to burn enough user and system time,
    refactor the "burn some cpu" utility into t/burn.pl, use that also
    in t/times.t.
  * Fix a testing problem in NetBSD for t/setrlimit.t,
    the tests were misnumbered.
  * Silence compilation warnings coming from Perl 5.18.0.
  * Clarify the license to be Artistic 2.0 or LGPL 2.0.
  * Regenerate ppport.h with Perl 5.18.0.
  * Release 1.2905.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Thu Mar 25 2010 anicka@suse.cz
- update to 1.2904
  * Address rt.cpan.org #53856: memory leak in get_rlimits()
  * Address rt.cpan.org #53859: clarify get_rlimits() docs
* Thu Feb  4 2010 jengelh@medozas.de
- add comment about possible testcase failure
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Apr  6 2009 anicka@suse.cz
- update to 1.2903
  * Address rt.cpan.org #44082:
  "Bug in compiler detection (Makefile.PL)" (for AIX xlc)
* Fri Jan 23 2009 anicka@suse.cz
- update to 1.2902
  * Lowered the "0.95 of the current limit" down to
  "0.75 of the current limit" in setrlimit.t so that
  more memory-constrained systems (like 2MB or less of
  default stack) have slightly more chance of completing the test.
  The 0.75 also has more chance of aligning with page sizes.
  * The scalar context return of getrlimit() was documented
  to return an object, even though it really returned the
  soft limit. Fixed the documentation.
  * Judging by the cpantesters reports no netbsd has a functional
  RLIMIT_STACK, so skipping the test in all of them.
  * netbsd-alpha does not have a functional RLIMIT_STACK,
  reported by David Cantrell.  Skip the test, and document
  as a known issue.
- remove the last patch, because upstream prefers fixing documentation
  before fixing the behavior. We are compatible with the upstream now,
  but not with our last release.
* Tue Nov 25 2008 anicka@suse.cz
- getrlimit: return object in scalar context  according to
  the documentation (bnc#446693)
* Mon Mar  3 2008 anicka@suse.cz
- update to 1.2901
  * Rewrite the setrlimit.t test.
  * Allow calling getrlimit/setrlimit and getpriority/setpriority
    with the string names ("RLIMIT_NPROC", for example).
  * Include ppport.h (generated with perl 5.8.8), reshuffle
    system header includes appropriately.
- drop setrlimit.t patch
* Sun Jan 13 2008 coolo@suse.de
- take a patch from fedora to make it build
* Fri Oct 27 2006 dmueller@suse.de
- don't build as root
* Wed Jul 12 2006 anicka@suse.cz
- update to 1.28
  * many bugfixes added
- remove unneccessary test patch
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 uli@suse.de
- no test on ARM (unimplemented calls in QEMU)
* Fri Aug 13 2004 mjancar@suse.cz
- update to 1.24
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.23
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 mjancar@suse.cz
- fix test that assumed that it runs with nice 0
* Wed Aug  6 2003 mludvig@suse.cz
- package creation
